# APDaily
This package allows you to watch AP Classroom Videos automatically.
## Authors
- [@SarangaR](https://www.github.com/SarangaR)
## Installation
- Install the apdaily package with pip
```bash
  pip install apdaily
```
- Then copy the **scripts** folder from this repository and run the install script
#### Linux
```bash
  sudo ./scripts/apdaily-setup.sh
```
#### Windows
In an administrator command prompt:
```cmd
  scripts/apdaily-setup.bat
```


## Requirements
* pynput

